@@ -62,7 +62,7 @@ class Sales(Client):
         if granularityTimeZone:
             kwargs.update({'granularityTimeZone': granularityTimeZone})
         if 'sku' in kwargs:
-            kwargs.update({'sku': urllib.parse.quote_plus(kwargs.pop('sku'))})
+            kwargs.update({'sku': urllib.parse.quote(kwargs.pop('sku'), safe='')})
         return self._request(kwargs.pop('path'), params=kwargs)
 
     @staticmethod
@@ -79,4 +79,4 @@ class Sales(Client):
         if isinstance(datetime_obj, str):
             return datetime_obj
         fmt = '%Y-%m-%dT%H:%M:%S%z'
-        return datetime_obj.strftime(fmt)[:-2] + ':00'
+        return datetime_obj.astimezone().isoformat(timespec="seconds")
