@@ -97,9 +97,12 @@ class ReportType(str, Enum):
     GET_VENDOR_FORECASTING_REPORT = 'GET_VENDOR_FORECASTING_REPORT'
     GET_VENDOR_SALES_DIAGNOSTIC_REPORT = 'GET_VENDOR_SALES_DIAGNOSTIC_REPORT'
     GET_VENDOR_SALES_REPORT = 'GET_VENDOR_SALES_REPORT'
+    GET_VENDOR_REAL_TIME_SALES_REPORT = 'GET_VENDOR_REAL_TIME_SALES_REPORT'
     GET_VENDOR_TRAFFIC_REPORT = 'GET_VENDOR_TRAFFIC_REPORT'
+    GET_VENDOR_REAL_TIME_TRAFFIC_REPORT = 'GET_VENDOR_REAL_TIME_TRAFFIC_REPORT'
     GET_VENDOR_INVENTORY_HEALTH_AND_PLANNING_REPORT = 'GET_VENDOR_INVENTORY_HEALTH_AND_PLANNING_REPORT'
     GET_VENDOR_INVENTORY_REPORT = 'GET_VENDOR_INVENTORY_REPORT'
+    GET_VENDOR_REAL_TIME_INVENTORY_REPORT = 'GET_VENDOR_REAL_TIME_INVENTORY_REPORT'
     GET_VENDOR_DEMAND_FORECAST_REPORT = 'GET_VENDOR_DEMAND_FORECAST_REPORT'
     GET_PROMOTION_PERFORMANCE_REPORT = 'GET_PROMOTION_PERFORMANCE_REPORT'
     GET_BRAND_ANALYTICS_MARKET_BASKET_REPORT = 'GET_BRAND_ANALYTICS_MARKET_BASKET_REPORT'
@@ -117,4 +120,3 @@ class ReportType(str, Enum):
     GET_XML_VAT_INVOICE_DATA_REPORT = "GET_XML_VAT_INVOICE_DATA_REPORT"
     GET_B2B_PRODUCT_OPPORTUNITIES_RECOMMENDED_FOR_YOU = "GET_B2B_PRODUCT_OPPORTUNITIES_RECOMMENDED_FOR_YOU"
     GET_B2B_PRODUCT_OPPORTUNITIES_NOT_YET_ON_AMAZON = "GET_B2B_PRODUCT_OPPORTUNITIES_NOT_YET_ON_AMAZON"
-
